@@ -12,15 +12,17 @@
  * @author     Tomas V.V.Cox <cox@idecnet.com>
  * @copyright  1997-2009 The Authors
  * @license    http://opensource.org/licenses/bsd-license.php New BSD License
- * @version    CVS: $Id: peclcmd.php 313023 2011-07-06 19:17:11Z dufuz $
+ * @version    CVS: $Id$
  * @link       http://pear.php.net/package/PEAR
  */
 
 /**
  * @nodep Gtk
  */
-if ('/var/www/pear/lib' != '@'.'include_path'.'@') {
-    ini_set('include_path', '/var/www/pear/lib');
+//the space is needed for windows include paths with trailing backslash
+// http://pear.php.net/bugs/bug.php?id=19482
+if ('/var/www/pear/lib ' != '@'.'include_path'.'@ ') {
+    ini_set('include_path', trim('/var/www/pear/lib '));
     $raw = false;
 } else {
     // this is a raw, uninstalled pear, either a cvs checkout, or php distro
